@@ -63,7 +63,7 @@ if __name__ == "__main__":
     # depot_daemon = DepotDaemon()
     # daemon_runner = runner.DaemonRunner(depot_daemon)
     # daemon_runner.do_action()
-    depot_daemon = DepotDaemon('depot.pid')
+    depot_daemon = DepotDaemon('/tmp/depot.pid')
     if parser.parse_args().status == "start":
         depot_daemon.start()
     elif parser.parse_args().status == "stop":
